PropsRead<Props extends PropsProvider<Props>> class

Reads the current PropsProvider without dependency. Will NOT trigger rebuilds when provider updates.

Constructors

PropsRead()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(BuildContext context) → Props
Read provider without subscribing to updates.
maybe(BuildContext context) → Props?
Nullable variant. Returns null if not found.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited